@@ -2,6 +2,8 @@
 
 from typing import List, TypedDict
 
+from typing_extensions import NotRequired
+
 from .nba_game_status import NbaGameStatus
 from .nba_game_extended_status import NbaGameExtendedStatus
 from .nba_game_location import NbaGameLocation
@@ -34,3 +36,4 @@ class NbaGameModel(TypedDict):
     gameDuration: int
     nPeriod: int
     hasOverTime: bool
+    hotnessScore: NotRequired[int]
