@@ -180,6 +180,20 @@ class DynamoDBTable(Generic[T]):
 
         return "'" + condition['value'] + "'"
 
+    def delete_attributes(self, hash_key: str, attribute_names: List[str], range_key: Optional[str] = None) -> None:
+        """Delete attributes of an item"""
+
+        request_key = {self.hash_key: hash_key}
+        if self.range_key and range_key:
+            request_key[self.range_key] = range_key
+
+        update_expression = f"""REMOVE {', '.join(attribute_names)}"""
+
+        self.table.update_item(
+            Key=request_key,
+            UpdateExpression=update_expression,
+        )
+
     def delete_item(self, value: str, range_key_value: Optional[str] = None):
         """Delete an item by his hash key"""
 
